Attribute VB_Name = "modEllipsoidData"
Option Explicit

Declare Function GetLocaleInfo Lib "kernel32" Alias "GetLocaleInfoA" (ByVal Locale As Long, ByVal LCType As Long, ByVal lpLCData As String, ByVal cchData As Long) As Long

Public Const LOCALE_USER_DEFAULT = &H400
Public Const LOCALE_SDECIMAL = &HE

Public sDECIMAL As String  'decimal separator [Dezimaltrennzeichen]
Public iDECIMAL As String  'ASCII number of decimal separator
Public RetVal   As Long    'return value from API call [Rckgabewert des API Aufrufes]
Public PI       As Double  'circle constant [Kreiszahl]
Public a        As Double  'semi-major axis [groe Halbachse]
Public b        As Double  'semi-minor axis [kleine Halbachse]
Public e        As Double  'numeric eccentricity [numerische Exzentrizitt]
Public f        As Double  'flattening [Abplattung]
Public PhiDeg   As Double  'geographic latitude (degrees) [geographische Breite (Grad)]
Public PhiRad   As Double  'geographic latitude (radian) [geographische Breite (Bogenma)]
Public PsiDeg   As Double  'geocentric latitude (degrees) [geozentrische Breite (Grad)]
Public PsiRad   As Double  'geocentric latitude (radian) [geozentrische Breite (Bogenma]
Public PhiMax   As Double  'max. geographic latitude (degrees) [max. geographische Breite (Grad)]
Public PhiStep  As Double  'stepping of geographic latitude (degrees) [Schrittweite der geographische Breite (Grad)]
Public Area     As Double  'area between the equator and the selected geographic latitude [Flcheninhalt zwischen dem quator und dem geographischen Breitengrad]
Public Arc      As Double  'arc length along longitude between the equator and the selected geographic latitude [Bogenlnge entlang des Lngengrades zwischen dem quator und dem geographischen Breitengrad]
Public Radius   As Double  'radius from the center of the ellippsoid to the geographic latitude [Radius vom Mittelpunkt des Ellipsoids zum geographischen Breitengrad]
Public HeightP  As Double  'distance from the center of the ellipsoid to the center of the primitive circle defined by the geographic latitude [Hhe vom Mittelpunk des Ellipsoids zum Mittelpunkt der Kreisflche die durch die geographische Breite beschrieben wird]
Public RadiusP  As Double  'radius of the primitiv circle defined by the geographic latitude [Radius der Kreisflche die durch die geographische Breite beschrieben wird]
Public CircumP  As Double  'circumference of the primitive circle defined by the geographic latitude [Umfang der Kreisflche die durch die geographische Breite beschrieben wird]
Public Text     As String  'Results [Ergebnisse]
Public dLoop    As Single  'counter [Zhlvariable]
Public iLoop    As Integer 'counter [Zhlvariable]
Public dTemp    As Double

Public sEllipsoidTag(21)  As String
Public sEllipsoidTxt(21)  As String
Public dEllipsoidAxis(21) As Double
Public dEllipsoid1_f(21)  As Double
Public sDatumTag(191)     As String
Public sDatumTxt(191)     As String


Public Sub Main()
   PI = 4 * Atn(1)
   Call ReadLocalInfo
   frmEllipsoidData.Show
End Sub

Public Sub ReadLocalInfo()
   'determine your decimal seperator [Ermitteln des verwendeten Dezimaltrennzeichens]
   Dim sString As String * 100
   RetVal = GetLocaleInfo(LOCALE_USER_DEFAULT, LOCALE_SDECIMAL, sString, 99)
   sDECIMAL = LPSTR2VBStr(sString)
   iDECIMAL = Asc(sDECIMAL)
End Sub

Public Function LPSTR2VBStr(ByVal sVar As String)
    Dim lNullPos As Long
    lNullPos = InStr(sVar, Chr(0))
    If lNullPos > 0 Then
        LPSTR2VBStr = Left(sVar, lNullPos - 1)
    Else
        LPSTR2VBStr = ""
    End If
End Function

Public Function Phi2Psi(Phi As Double, e As Double) As Double
   'convert geographic to geocentric latitude [umrechnen von geographischer zu geozentrischer Breite]
   'Phi = geographic latitude (degrees) [geographische Breite (Grad)]
   'e = numeric eccentricity [numerische Exzentrizitt]
   Phi2Psi = Atn((1 - e ^ 2) * Tan(Deg2Rad(Phi)))
   Phi2Psi = Rad2Deg(Phi2Psi)
   'Phi2Psi = geocentric latitude (degrees) [geozentrische Breite (Grad)]
End Function

Public Function Deg2Rad(Deg As Double) As Double
   'convert degrees to radian [umwandeln von Grad- in Bogenma]
   'Deg = degrees [Grad]
   Deg2Rad = Deg * (PI / 180)
End Function

Public Function Rad2Deg(Rad As Double) As Double
   'convert radian to degrees [umwandeln vom Bogenma in Grad]
   'Rad = radian [Bogenma]
   Rad2Deg = Rad * (180 / PI)
End Function

Public Function EllipsoidArea(b As Double, e As Double, Psi As Double) As Variant
   'calculate the area of the surface of the ellipsoid between the equator and the geographic latitude
   '[berechnet den Flcheninhalt der Ellipsoidoberflche zwischen dem quator und dem geographischen Breitengrad]
   
   'b = semi-minor axis [Kleine Halbachse]
   'e = numeric eccentricity [numerische Exzentrizitt]
   'Psi = geocentric latitude (radian!) [geozentrische Breite [Bogenma!]
   EllipsoidArea = b ^ 2 * PI * (((Sin(Psi) * Sqr(1 - e ^ 2 * Cos(Psi) ^ 2 * (2 - e ^ 2))) / ((1 - e ^ 2) * (1 - e ^ 2 * Cos(Psi) ^ 2))) + (1 / e) * Log(((e * Sin(Psi)) + Sqr(1 - e ^ 2 * Cos(Psi) ^ 2 * (2 - e ^ 2))) / (Sqr(1 - e ^ 2) * Sqr(1 - e ^ 2 * Cos(Psi) ^ 2))))
End Function

Public Function ArcLength(PhiStart As Double, PhiEnd As Double, a As Double, b As Double) As Double
   'calculate the arc length of an ellipse with the Gauss integration
   'berechnet die Bgenlnge einer Ellipse mit Hilfe der Gau Integration
   'PhiStart = starting angle (geographic latitude (degrees)) [Anfangswinkel (geographische Breite (Grad)]
   'PhiEnd = final angle (geographic latitude (degrees)) [Endwinkel (geographische Breite (Grad)]
   'a = semi-major axis [groe Halbachse]
   'e = numeric eccentricity [numerische Exzentrizitt]
   Dim Phi0     As Double
   Dim Phi1     As Double
   Dim gi_x(32) As Double
   Dim gi_w(32) As Double
   Dim gi_t(32) As Double
   Dim gi_s(32) As Double
   Dim N        As Integer 'counter [Zhlvariable]
   Dim Integral As Double
   Phi0 = Atn((b / a) * Tan(Deg2Rad(PhiStart)))
   Phi1 = Atn((b / a) * Tan(Deg2Rad(PhiEnd)))
   N = 32
   gi_x(0) = 0.024350292663424
   gi_x(1) = 0.072993121787799
   gi_x(2) = 0.12146281929612
   gi_x(3) = 0.16964442042399
   gi_x(4) = 0.21742364374001
   gi_x(5) = 0.26468716220877
   gi_x(6) = 0.31132287199021
   gi_x(7) = 0.35722015833767
   gi_x(8) = 0.40227015796399
   gi_x(9) = 0.44636601725346
   gi_x(10) = 0.48940314570705
   gi_x(11) = 0.53127946401989
   gi_x(12) = 0.57189564620263
   gi_x(13) = 0.61115535517239
   gi_x(14) = 0.64896547125466
   gi_x(15) = 0.68523631305423
   gi_x(16) = 0.71988185017161
   gi_x(17) = 0.75281990726053
   gi_x(18) = 0.78397235894334
   gi_x(19) = 0.8132653151228
   gi_x(20) = 0.84062929625258
   gi_x(21) = 0.86599939815409
   gi_x(22) = 0.88931544599511
   gi_x(23) = 0.9105221370785
   gi_x(24) = 0.92956917213194
   gi_x(25) = 0.9464113748584
   gi_x(26) = 0.96100879965205
   gi_x(27) = 0.97332682778991
   gi_x(28) = 0.98333625388463
   gi_x(29) = 0.99101337147674
   gi_x(30) = 0.99634011677196
   gi_x(31) = 0.99930504173577
   gi_w(0) = 0.04869095700914
   gi_w(1) = 0.048575467441503
   gi_w(2) = 0.048344762234803
   gi_w(3) = 0.047999388596458
   gi_w(4) = 0.04754016571483
   gi_w(5) = 0.04696818281621
   gi_w(6) = 0.046284796581314
   gi_w(7) = 0.045491627927418
   gi_w(8) = 0.044590558163757
   gi_w(9) = 0.043583724529323
   gi_w(10) = 0.042473515123654
   gi_w(11) = 0.041262563242624
   gi_w(12) = 0.03995374113272
   gi_w(13) = 0.038550153178616
   gi_w(14) = 0.03705512854024
   gi_w(15) = 0.035472213256882
   gi_w(16) = 0.033805161837142
   gi_w(17) = 0.032057928354852
   gi_w(18) = 0.030234657072402
   gi_w(19) = 0.028339672614259
   gi_w(20) = 0.026377469715055
   gi_w(21) = 0.024352702568711
   gi_w(22) = 0.022270173808383
   gi_w(23) = 0.02013482315353
   gi_w(24) = 0.017951715775697
   gi_w(25) = 0.015726030476025
   gi_w(26) = 0.013463047896719
   gi_w(27) = 0.011168139460131
   gi_w(28) = 8.8467598263639E-03
   gi_w(29) = 6.5044579689784E-03
   gi_w(30) = 4.1470332605625E-03
   gi_w(31) = 1.7832807216964E-03
   Integral = 0
   For N = 0 To 31
      gi_t(N) = (Phi1 - Phi0) / 2 * gi_x(N) + (Phi1 + Phi0) / 2
      gi_s(N) = -(Phi1 - Phi0) / 2 * gi_x(N) + (Phi1 + Phi0) / 2
      Integral = Integral + gi_w(N) * (ArcFunction(gi_t(N), a, b) + ArcFunction(gi_s(N), a, b))
   Next N
   ArcLength = (Phi1 - Phi0) / 2 * Integral
End Function

Public Function ArcFunction(x As Double, a As Double, b As Double) As Double
   'call from the For - Next Loop of the ArcLength function
   'Aufruf aus der For-Next Schleife der ArcLength Funktion
   'x = value from ArcLength function [bergabewert aus ArcLength Funktion]
   'a = semi-major axis [groe Halbachse]
   'b = semi-minor axis [kleine Halbachse]
   ArcFunction = Sqr(b ^ 2 + (a ^ 2 - b ^ 2) * Sin(x) ^ 2)
End Function

Public Function Circumference(a As Double, e As Double) As Double
   'calculate the circumference (arc length) of the entrie ellipse (longitude)
   'berechnet den Unfang (Bogenlnge) der gesamten Ellipse (Lngengrad)
   'a = semi-major axis [groe Halbachse]
   'e = numeric eccentricity [numerische Exzentrizitt]
   Dim value1(100) As Double
   Dim value2      As Double
   Dim Odd         As Double  'odd numerator [ungerader Zhler]
   Dim Even        As Double  'even denominator [gerader Nenner]
   Dim N           As Integer 'counter [Zhlvariable]
   Odd = 1
   Even = 1
   value2 = 1
   For N = 1 To 100 Step 1
      Odd = Odd * (2 * N - 1)
      Even = Even * (2 * N)
      value1(N) = ((Odd / Even) ^ 2) * ((e ^ (2 * N)) / (2 * N - 1))
      value2 = value2 - value1(N)
   Next N
   Circumference = 2 * PI * a * value2
End Function

Public Function RadiusPsi(Phi As Double, a As Double, e As Double) As Double
   'calculate the radius from the center of the ellipsoid to the geographic latitude
   'berechnet den Radius vom Mittelpunkt des Ellipsoids zum geographischen Breitengrad
   'Phi = geographic latitude (degrees) [geographische Breite (Grad)]
   'a = semi-major axis [groe Halbachse]
   'e = numeric eccentricity [numerische Exzentrizitt]
   Dim SinPhi As Double 'Sine of Phi [Sinus Phi]
   Dim SinPsi As Double 'Sine of Psi [Sinus Psi]
   SinPhi = Sin(Deg2Rad(Phi))
   SinPsi = Sin(Deg2Rad(Phi2Psi(Phi, e)))
   If SinPsi = 0 Then
      RadiusPsi = a
   Else
      RadiusPsi = ((((1 - e ^ 2) * a) / (Sqr(1 - e ^ 2 * SinPhi ^ 2))) * SinPhi) / SinPsi
   End If
End Function


Public Sub FillList()
   Dim iLoop As Integer
   sEllipsoidTag(0) = "AA"
   sEllipsoidTxt(0) = "Airy 1830"
   dEllipsoidAxis(0) = 6377563.396
   dEllipsoid1_f(0) = 299.3249646
   sEllipsoidTag(1) = "AM"
   sEllipsoidTxt(1) = "Modified Airy"
   dEllipsoidAxis(1) = 6377340.189
   dEllipsoid1_f(1) = 299.3249646
   sEllipsoidTag(2) = "AN"
   sEllipsoidTxt(2) = "Australian National"
   dEllipsoidAxis(2) = 6378160
   dEllipsoid1_f(2) = 298.25
   sEllipsoidTag(3) = "BN"
   sEllipsoidTxt(3) = "Bessel 1841 (Namibia)"
   dEllipsoidAxis(3) = 6377483.865
   dEllipsoid1_f(3) = 299.1528128
   sEllipsoidTag(4) = "BR"
   sEllipsoidTxt(4) = "Bessel 1841"
   dEllipsoidAxis(4) = 6377397.155
   dEllipsoid1_f(4) = 299.1528128
   sEllipsoidTag(5) = "CC"
   sEllipsoidTxt(5) = "Clarke 1866"
   dEllipsoidAxis(5) = 6378206.4
   dEllipsoid1_f(5) = 294.9786982
   sEllipsoidTag(6) = "CD"
   sEllipsoidTxt(6) = "Clarke 1880"
   dEllipsoidAxis(6) = 6379249.145
   dEllipsoid1_f(6) = 293.465
   sEllipsoidTag(7) = "EA"
   sEllipsoidTxt(7) = "Everest (India 1830)"
   dEllipsoidAxis(7) = 6377276.345
   dEllipsoid1_f(7) = 300.8017
   sEllipsoidTag(8) = "EB"
   sEllipsoidTxt(8) = "Everest (Sabah & Sarawak)"
   dEllipsoidAxis(8) = 6377298.556
   dEllipsoid1_f(8) = 300.8017
   sEllipsoidTag(9) = "EC"
   sEllipsoidTxt(9) = "Everest (India 1956)"
   dEllipsoidAxis(9) = 6377301.243
   dEllipsoid1_f(9) = 300.8017
   sEllipsoidTag(10) = "ED"
   sEllipsoidTxt(10) = "Everest (W. Malaysia 1969)"
   dEllipsoidAxis(10) = 6377295.664
   dEllipsoid1_f(10) = 300.8017
   sEllipsoidTag(11) = "EE"
   sEllipsoidTxt(11) = "Everest (W. Malaysia & Singapore 1948)"
   dEllipsoidAxis(11) = 6377304.063
   dEllipsoid1_f(11) = 300.8017
   sEllipsoidTag(12) = "FA"
   sEllipsoidTxt(12) = "Modified Fischer 1960"
   dEllipsoidAxis(12) = 6378155
   dEllipsoid1_f(12) = 298.3
   sEllipsoidTag(13) = "HE"
   sEllipsoidTxt(13) = "Helmert 1906"
   dEllipsoidAxis(13) = 6378200
   dEllipsoid1_f(13) = 298.3
   sEllipsoidTag(14) = "HO"
   sEllipsoidTxt(14) = "Hough 1960"
   dEllipsoidAxis(14) = 6378270
   dEllipsoid1_f(14) = 297
   sEllipsoidTag(15) = "IN"
   sEllipsoidTxt(15) = "International 1924"
   dEllipsoidAxis(15) = 6378388
   dEllipsoid1_f(15) = 297
   sEllipsoidTag(16) = "KA"
   sEllipsoidTxt(16) = "Krassovsky 1940"
   dEllipsoidAxis(16) = 6378245
   dEllipsoid1_f(16) = 298.3
   sEllipsoidTag(17) = "RF"
   sEllipsoidTxt(17) = "Geodetic Reference System 1980 (GRS 80)"
   dEllipsoidAxis(17) = 6378137
   dEllipsoid1_f(17) = 298.257222101
   sEllipsoidTag(18) = "SA"
   sEllipsoidTxt(18) = "South American 1969"
   dEllipsoidAxis(18) = 6378160
   dEllipsoid1_f(18) = 298.25
   sEllipsoidTag(19) = "WD"
   sEllipsoidTxt(19) = "WGS 72"
   dEllipsoidAxis(19) = 6378135
   dEllipsoid1_f(19) = 298.26
   sEllipsoidTag(20) = "WE"
   sEllipsoidTxt(20) = "WGS 84"
   dEllipsoidAxis(20) = 6378137
   dEllipsoid1_f(20) = 298.257223563
   sEllipsoidTag(21) = "SD"
   sEllipsoidTxt(21) = "self defined"
   dEllipsoidAxis(21) = 5
   dEllipsoid1_f(21) = 2.5
      
   
   sDatumTag(0) = "CD"
   sDatumTxt(0) = "Adindan  (Ethiopia)"
   sDatumTag(1) = "CD"
   sDatumTxt(1) = "Adindan  (Sudan)"
   sDatumTag(2) = "CD"
   sDatumTxt(2) = "Adindan  (Mali)"
   sDatumTag(3) = "CD"
   sDatumTxt(3) = "Adindan  (Senegal)"
   sDatumTag(4) = "CD"
   sDatumTxt(4) = "Adindan  (Burkina Faso)"
   sDatumTag(5) = "CD"
   sDatumTxt(5) = "Adindan  (Cameroon)"
   sDatumTag(6) = "CD"
   sDatumTxt(6) = "Adindan  (MEAN FOR Ethiopia, Sudan)"
   sDatumTag(7) = "KA"
   sDatumTxt(7) = "Afgooye  (Somalia)"
   sDatumTag(8) = "CD"
   sDatumTxt(8) = "Antigua Island Astro 1943  (Antigua (Leeward Islands))"
   sDatumTag(9) = "IN"
   sDatumTxt(9) = "Ainel Abd 1970  (Bahrain)"
   sDatumTag(10) = "IN"
   sDatumTxt(10) = "Ainel Abd 1970  (Saudi Arabia)"
   sDatumTag(11) = "AN"
   sDatumTxt(11) = "Anna1 Astro 1965  (Cocos Islands)"
   sDatumTag(12) = "CD"
   sDatumTxt(12) = "Arc 1950  (Botswana)"
   sDatumTag(13) = "CD"
   sDatumTxt(13) = "Arc 1950  (Lesotho)"
   sDatumTag(14) = "CD"
   sDatumTxt(14) = "Arc 1950  (Malawi)"
   sDatumTag(15) = "CD"
   sDatumTxt(15) = "Arc 1950  (Swaziland)"
   sDatumTag(16) = "CD"
   sDatumTxt(16) = "Arc 1950  (Zaire)"
   sDatumTag(17) = "CD"
   sDatumTxt(17) = "Arc 1950  (Zambia)"
   sDatumTag(18) = "CD"
   sDatumTxt(18) = "Arc 1950  (Zimbabwe)"
   sDatumTag(19) = "CD"
   sDatumTxt(19) = "Arc 1950  (Burundi)"
   sDatumTag(20) = "CD"
   sDatumTxt(20) = "Arc 1950  (MEAN FOR Botswana, Lesotho, Malawi, Swaziland, Zaire Zambia, Zimbabwe)"
   sDatumTag(21) = "CD"
   sDatumTxt(21) = "Arc 1960  (MEAN FOR Kenya, Tanzania)"
   sDatumTag(22) = "IN"
   sDatumTxt(22) = "Ascension Island 1958  (Ascension Island)"
   sDatumTag(23) = "CD"
   sDatumTxt(23) = "Montserrat Island Astro 1958  (Montserrat (Leeward Islands))"
   sDatumTag(24) = "IN"
   sDatumTxt(24) = "Astronomical Station 1952  (Marcus Island)"
   sDatumTag(25) = "IN"
   sDatumTxt(25) = "Astro Beacon E 1945  (Iwo Jima)"
   sDatumTag(26) = "AN"
   sDatumTxt(26) = "Australian Geodetic 1966  (Australia & Tasmania)"
   sDatumTag(27) = "AN"
   sDatumTxt(27) = "Australian Geodetic 1984  (Australia & Tasmania)"
   sDatumTag(28) = "BR"
   sDatumTxt(28) = "Djakarta (Batavia)  (Indonesia (Sumatra))"
   sDatumTag(29) = "CC"
   sDatumTxt(29) = "Bermuda 1957  (Bermuda)"
   sDatumTag(30) = "IN"
   sDatumTxt(30) = "Bissau  (Guinea-Bissau)"
   sDatumTag(31) = "IN"
   sDatumTxt(31) = "Bogota Observatory  (Colombia)"
   sDatumTag(32) = "BR"
   sDatumTxt(32) = "Bukit Rimpah  (Indonesia (Bangka Belitung Islands))"
   sDatumTag(33) = "CC"
   sDatumTxt(33) = "Cape Canaveral  (Bahamas, Florida)"
   sDatumTag(34) = "IN"
   sDatumTxt(34) = "Campo Inchauspe  (Argentina)"
   sDatumTag(35) = "IN"
   sDatumTxt(35) = "Canton Astro 1966  (Phoenix Islands)"
   sDatumTag(36) = "CD"
   sDatumTxt(36) = "Cape  (South Africa)"
   sDatumTag(37) = "IN"
   sDatumTxt(37) = "Camp Area Astro  (Antarctica (McMurdo Camp Area))"
   sDatumTag(38) = "CD"
   sDatumTxt(38) = "Carthage  (Tunisia)"
   sDatumTag(39) = "IN"
   sDatumTxt(39) = "Chatham Island Astro 1971  (New Zealand (Chatham Island))"
   sDatumTag(40) = "IN"
   sDatumTxt(40) = "Chua Astro  (Paraguay)"
   sDatumTag(41) = "IN"
   sDatumTxt(41) = "Corrego Alegre  (Brazil)"
   sDatumTag(42) = "CD"
   sDatumTxt(42) = "Dabola  (Guinea)"
   sDatumTag(43) = "IN"
   sDatumTxt(43) = "GUX1 Astro  (Guadalcanal Island)"
   sDatumTag(44) = "IN"
   sDatumTxt(44) = "Easter Island 1967  (Easter Island)"
   sDatumTag(45) = "HO"
   sDatumTxt(45) = "Wake-Eniwetok1960  (Marshall Islands)"
   sDatumTag(46) = "IN"
   sDatumTxt(46) = "European 1950  (MEAN FOR Austria, Denmark, France, West Germany, Netherlands, Switzerland)"
   sDatumTag(47) = "IN"
   sDatumTxt(47) = "European 1950  (Greece)"
   sDatumTag(48) = "IN"
   sDatumTxt(48) = "European 1950  (Finland, Norway)"
   sDatumTag(49) = "IN"
   sDatumTxt(49) = "European 1950  (Portugal, Spain)"
   sDatumTag(50) = "IN"
   sDatumTxt(50) = "European 1950  (Cyprus)"
   sDatumTag(51) = "IN"
   sDatumTxt(51) = "European 1950  (Egypt)"
   sDatumTag(52) = "IN"
   sDatumTxt(52) = "European 1950  (England, Channel Islands, Scotland, Shetland Islands)"
   sDatumTag(53) = "IN"
   sDatumTxt(53) = "European 1950  (Iran)"
   sDatumTag(54) = "IN"
   sDatumTxt(54) = "European 1950  (Italy (Sardinia))"
   sDatumTag(55) = "IN"
   sDatumTxt(55) = "European 1950  (Italy (Sicily))"
   sDatumTag(56) = "IN"
   sDatumTxt(56) = "European 1950  (England, Ireland, Scotland, Shetland Islands)"
   sDatumTag(57) = "IN"
   sDatumTxt(57) = "European 1950  (Malta)"
   sDatumTag(58) = "IN"
   sDatumTxt(58) = "European 1950  (MEAN FOR Austria, Belgium, Denmark, Finland, France, West Germany, Gibralter, Greece, Italy, Luxembourg, Netherlands, Norway, Portugal, Spain, Sweden, Switzerland)"
   sDatumTag(59) = "IN"
   sDatumTxt(59) = "European 1950  (MEAN FOR Iraq, Israel, Jordan, Lebanon, Kuwait, Saudi Arabia, Syria)"
   sDatumTag(60) = "IN"
   sDatumTxt(60) = "European 1979  (MEAN FOR Austria, Finland, Netherlands, Norway, Spain, Sweden, Switzerland)"
   sDatumTag(61) = "CD"
   sDatumTxt(61) = "Oman  (Oman)"
   sDatumTag(62) = "IN"
   sDatumTxt(62) = "Observatorio Meteorologico 1939  (Azores (Corvo FloresIslands))"
   sDatumTag(63) = "CD"
   sDatumTxt(63) = "Fort Thomas 1955  (Nevis, St,Kitts (Leeward Islands))"
   sDatumTag(64) = "IN"
   sDatumTxt(64) = "Gan 1970  (Republic of Maldives)"
   sDatumTag(65) = "IN"
   sDatumTxt(65) = "Geodetic Datum 1949  (New Zealand)"
   sDatumTag(66) = "IN"
   sDatumTxt(66) = "DOS 1968  (New Georgia Islands (Gizo Island))"
   sDatumTag(67) = "IN"
   sDatumTxt(67) = "Graciosa Base SW 1948  (Azores (Faial, Graciosa, Pico, Sao Jorge, Terceira))"
   sDatumTag(68) = "BR"
   sDatumTxt(68) = "GunungSegara  (Indonesia (Kalimantan))"
   sDatumTag(69) = "CC"
   sDatumTxt(69) = "Guam 1963  (Guam)"
   sDatumTag(70) = "IN"
   sDatumTxt(70) = "Herat North  (Afghanistan)"
   sDatumTag(71) = "IN"
   sDatumTxt(71) = "Provisional South Chilean 1963  (South Chile (Near 53 0 S) (HitoXVIII))"
   sDatumTag(72) = "IN"
   sDatumTxt(72) = "Hjorsey 1955  (Iceland)"
   sDatumTag(73) = "IN"
   sDatumTxt(73) = "HongKong 1963  (Hong Kong)"
   sDatumTag(74) = "IN"
   sDatumTxt(74) = "Hu-Tzu-Shan  (Taiwan)"
   sDatumTag(75) = "IN"
   sDatumTxt(75) = "Bellevue (IGN)  (Efate & Erromango Islands)"
   sDatumTag(76) = "EA"
   sDatumTxt(76) = "Indian  (Bangladesh)"
   sDatumTag(77) = "EC"
   sDatumTxt(77) = "Indian  (India, Nepal)"
   sDatumTag(78) = "EA"
   sDatumTxt(78) = "Indian 1954  (Thailand, Vietnam)"
   sDatumTag(79) = "EA"
   sDatumTxt(79) = "Indian 1975  (Thailand)"
   sDatumTag(80) = "AM"
   sDatumTxt(80) = "Ireland 1965  (Ireland)"
   sDatumTag(81) = "IN"
   sDatumTxt(81) = "ISTS061 Astro 1968  (South Georgia Islands)"
   sDatumTag(82) = "IN"
   sDatumTxt(82) = "ISTS073 Astro 1969  (Diego Garcia)"
   sDatumTag(83) = "IN"
   sDatumTxt(83) = "Johnston Island 1961  (Johnston Island)"
   sDatumTag(84) = "EA"
   sDatumTxt(84) = "Kandawala  (Sri Lanka)"
   sDatumTag(85) = "EE"
   sDatumTxt(85) = "Kertau 1948  (West Malaysia & Singapore)"
   sDatumTag(86) = "IN"
   sDatumTxt(86) = "KerguelenIsland 1949  (Kerguelen Island)"
   sDatumTag(87) = "IN"
   sDatumTxt(87) = "Kusaie Astro 1951  (Caroline Islands)"
   sDatumTag(88) = "CC"
   sDatumTxt(88) = "L,C,5 Astro 1961  (Cayman Brac Island)"
   sDatumTag(89) = "CD"
   sDatumTxt(89) = "Leigon  (Ghana)"
   sDatumTag(90) = "CD"
   sDatumTxt(90) = "Liberia 1964  (Liberia)"
   sDatumTag(91) = "CC"
   sDatumTxt(91) = "Luzon  (Philippines (Excluding Mindanao))"
   sDatumTag(92) = "CC"
   sDatumTxt(92) = "Luzon  (Philippines (Mindanao))"
   sDatumTag(93) = "BR"
   sDatumTxt(93) = "Massawa  (Ethiopia (Eritrea))"
   sDatumTag(94) = "CD"
   sDatumTxt(94) = "Merchich  (Morocco)"
   sDatumTag(95) = "IN"
   sDatumTxt(95) = "Midway Astro 1961  (Midway Islands)"
   sDatumTag(96) = "CD"
   sDatumTxt(96) = "Mahe 1971  (Mahe Island)"
   sDatumTag(97) = "CD"
   sDatumTxt(97) = "Minna  (Cameroon)"
   sDatumTag(98) = "CD"
   sDatumTxt(98) = "Minna  (Nigeria)"
   sDatumTag(99) = "IN"
   sDatumTxt(99) = "Rome 1940  (Italy (Sardinia))"
   sDatumTag(100) = "CD"
   sDatumTxt(100) = "M'Poraloko  (Gabon)"
   sDatumTag(101) = "CD"
   sDatumTxt(101) = "Viti Levu 1916  (Fiji (Viti Levu Island))"
   sDatumTag(102) = "CD"
   sDatumTxt(102) = "Nahrwan  (Oman (Masirah Island))"
   sDatumTag(103) = "CD"
   sDatumTxt(103) = "Nahrwan  (United Arab Emirates)"
   sDatumTag(104) = "CD"
   sDatumTxt(104) = "Nahrwan  (Saudi Arabia)"
   sDatumTag(105) = "IN"
   sDatumTxt(105) = "Naparima BWI  (Trinidad & Tobago)"
   sDatumTag(106) = "RF"
   sDatumTxt(106) = "North American 1983  (Alaska)"
   sDatumTag(107) = "RF"
   sDatumTxt(107) = "North American 1983  (Canada)"
   sDatumTag(108) = "RF"
   sDatumTxt(108) = "North American 1983  (CONUS)"
   sDatumTag(109) = "RF"
   sDatumTxt(109) = "North American 1983  (Mexico, Central America)"
   sDatumTag(110) = "CC"
   sDatumTxt(110) = "North American 1927  (MEAN FOR CONUS (East of Mississippi River) including Louisiana, Missouri, Minnesota)"
   sDatumTag(111) = "CC"
   sDatumTxt(111) = "North American 1927  (MEAN FOR CONUS (West of Mississippi River) excluding Louisiana, Missouri, Minnesota)"
   sDatumTag(112) = "CC"
   sDatumTxt(112) = "North American 1927  (MEAN FOR CONUS)"
   sDatumTag(113) = "CC"
   sDatumTxt(113) = "North American 1927  (Alaska)"
   sDatumTag(114) = "CC"
   sDatumTxt(114) = "North American 1927  (MEAN FOR Canada)"
   sDatumTag(115) = "CC"
   sDatumTxt(115) = "North American 1927  (Canada (Alberta, British Columbia))"
   sDatumTag(116) = "CC"
   sDatumTxt(116) = "North American 1927  (Canada (New Brunswick, Newfoundland, Nova Scotia, Quebec))"
   sDatumTag(117) = "CC"
   sDatumTxt(117) = "North American 1927  (Canada (Manitoba, Ontario))"
   sDatumTag(118) = "CC"
   sDatumTxt(118) = "North American 1927  (Canada (Northwest Territories, Saskatchewan))"
   sDatumTag(119) = "CC"
   sDatumTxt(119) = "North American 1927  (Canada (Yukon))"
   sDatumTag(120) = "CC"
   sDatumTxt(120) = "North American 1927  (Mexico)"
   sDatumTag(121) = "CC"
   sDatumTxt(121) = "North American 1927  (MEAN FOR Belize, CostaRica, El Salvador, Guatemala, Honduras, Nicaragua)"
   sDatumTag(122) = "CC"
   sDatumTxt(122) = "North American 1927  (Canal Zone)"
   sDatumTag(123) = "CC"
   sDatumTxt(123) = "North American 1927  (MEAN FOR Antigua, Barbados, Barbuda, Caicos Islands, Cuba, Dominican Republic, Grand Cayman, Jamaica, Turks Islands)"
   sDatumTag(124) = "CC"
   sDatumTxt(124) = "North American 1927  (Bahamas (Except San Salvador Island))"
   sDatumTag(125) = "CC"
   sDatumTxt(125) = "North American 1927  (Bahamas (San Salvador Island))"
   sDatumTag(126) = "CC"
   sDatumTxt(126) = "North American 1927  (Cuba)"
   sDatumTag(127) = "CC"
   sDatumTxt(127) = "North American 1927  (Greenland (Hayes Peninsula))"
   sDatumTag(128) = "HE"
   sDatumTxt(128) = "Old Egyptian 1907  (Egypt)"
   sDatumTag(129) = "AA"
   sDatumTxt(129) = "Ordnance Survey Great Britain 1936  (England)"
   sDatumTag(130) = "AA"
   sDatumTxt(130) = "Ordnance Survey Great Britain 1936  (England Isle of Man, Wales)"
   sDatumTag(131) = "AA"
   sDatumTxt(131) = "Ordnance Survey Great Britain 1936  (Scotland, Shetland, Islands)"
   sDatumTag(132) = "AA"
   sDatumTxt(132) = "Ordnance Survey Great Britain 1936  (Wales)"
   sDatumTag(133) = "AA"
   sDatumTxt(133) = "Ordnance Survey Great Britain 1936  (MEAN FOR England, Isle of Man, Scotland, Shetland Islands, Wales)"
   sDatumTag(134) = "CC"
   sDatumTxt(134) = "Old Hawaiian  (Hawaii)"
   sDatumTag(135) = "CC"
   sDatumTxt(135) = "Old Hawaiian  (Kauai)"
   sDatumTag(136) = "CC"
   sDatumTxt(136) = "Old Hawaiian  (Maui)"
   sDatumTag(137) = "CC"
   sDatumTxt(137) = "Old Hawaiian  (Oahu)"
   sDatumTag(138) = "CC"
   sDatumTxt(138) = "Old Hawaiian  (MEAN FOR Hawaii, Kauai, Maui, Oahu)"
   sDatumTag(139) = "CD"
   sDatumTxt(139) = "Ayabelle Lighthouse  (Djibouti)"
   sDatumTag(140) = "IN"
   sDatumTxt(140) = "Pitcairn Astro 1967  (Pitcairn Island)"
   sDatumTag(141) = "IN"
   sDatumTxt(141) = "Picodelas Nieves  (Canary Islands)"
   sDatumTag(142) = "IN"
   sDatumTxt(142) = "PortoSanto1936  (Porto Santo, Madeira Islands)"
   sDatumTag(143) = "IN"
   sDatumTxt(143) = "Provisional South American 1956  (Bolivia)"
   sDatumTag(144) = "IN"
   sDatumTxt(144) = "Provisional South American 1956  (Northern Chile (Near 19 0 S))"
   sDatumTag(145) = "IN"
   sDatumTxt(145) = "Provisional South American 1956  (Southern Chile (Near 43 0 S))"
   sDatumTag(146) = "IN"
   sDatumTxt(146) = "Provisional South American 1956  (Colombia)"
   sDatumTag(147) = "IN"
   sDatumTxt(147) = "Provisional South American 1956  (Ecuador)"
   sDatumTag(148) = "IN"
   sDatumTxt(148) = "Provisional South American 1956  (Guyana)"
   sDatumTag(149) = "IN"
   sDatumTxt(149) = "Provisional South American 1956  (Peru)"
   sDatumTag(150) = "IN"
   sDatumTxt(150) = "Provisional South American 1956  (Venezuela)"
   sDatumTag(151) = "IN"
   sDatumTxt(151) = "Provisional South American 1956  (MEAN FOR Bolivia, Chile, Colombia, Ecuador, Guyana, Peru, Venezuela)"
   sDatumTag(152) = "CD"
   sDatumTxt(152) = "Point 58  (MEAN FOR Burkina Faso & Niger)"
   sDatumTag(153) = "CD"
   sDatumTxt(153) = "Pointe Noire 1948  (Congo)"
   sDatumTag(154) = "CC"
   sDatumTxt(154) = "Puerto Rico  (PuertoRico VirginIslands)"
   sDatumTag(155) = "IN"
   sDatumTxt(155) = "Qatar National  (Qatar)"
   sDatumTag(156) = "IN"
   sDatumTxt(156) = "Qornoq  (Greenland(South))"
   sDatumTag(157) = "IN"
   sDatumTxt(157) = "Reunion  (Mascarene Islands)"
   sDatumTag(158) = "IN"
   sDatumTxt(158) = "Santo (DOS) 1965  (Espirito Santo Island)"
   sDatumTag(159) = "SA"
   sDatumTxt(159) = "South American 1969  (Argentina)"
   sDatumTag(160) = "SA"
   sDatumTxt(160) = "South American 1969  (Bolivia)"
   sDatumTag(161) = "SA"
   sDatumTxt(161) = "South American 1969  (Brazil)"
   sDatumTag(162) = "SA"
   sDatumTxt(162) = "South American 1969  (Chile)"
   sDatumTag(163) = "SA"
   sDatumTxt(163) = "South American 1969  (Colombia)"
   sDatumTag(164) = "SA"
   sDatumTxt(164) = "South American 1969  (Ecuador (excluding Galapagos Islands))"
   sDatumTag(165) = "SA"
   sDatumTxt(165) = "South American 1969  (Guyana)"
   sDatumTag(166) = "SA"
   sDatumTxt(166) = "South American 1969  (Paraguay)"
   sDatumTag(167) = "SA"
   sDatumTxt(167) = "South American 1969  (Peru)"
   sDatumTag(168) = "SA"
   sDatumTxt(168) = "South American 1969  (Ecuador (Baltra, Galapagos Islands))"
   sDatumTag(169) = "SA"
   sDatumTxt(169) = "South American 1969  (Trinidad &Tobago)"
   sDatumTag(170) = "SA"
   sDatumTxt(170) = "South American 1969  (Venezuela)"
   sDatumTag(171) = "SA"
   sDatumTxt(171) = "South American 1969  (MEAN FOR Argentina, Bolivia, Brazil, Chile, Colombia, Ecuador, Guyana, Paraguay, Peru, Trinidad &Tobago, Venezuela)"
   sDatumTag(172) = "IN"
   sDatumTxt(172) = "Sao Braz  (Azores (Sao Miguel, Santa Maria Islands))"
   sDatumTag(173) = "IN"
   sDatumTxt(173) = "Sapper Hill 1943  (East Falkland Island)"
   sDatumTag(174) = "BN"
   sDatumTxt(174) = "Schwarzeck  (Namibia)"
   sDatumTag(175) = "IN"
   sDatumTxt(175) = "Selvagem Grande 1938  (Salvage Islands)"
   sDatumTag(176) = "IN"
   sDatumTxt(176) = "Astro DOS 71/4  (St, Helena Island)"
   sDatumTag(177) = "FA"
   sDatumTxt(177) = "South Asia  (Singapore)"
   sDatumTag(178) = "IN"
   sDatumTxt(178) = "Tananarive Observatory 1925  (Madagascar)"
   sDatumTag(179) = "IN"
   sDatumTxt(179) = "Tristan Astro 1968  (Tristanda Cunha)"
   sDatumTag(180) = "EB"
   sDatumTxt(180) = "Timbalai 1948  (Brunei, East Malaysia (Sabah, Sarawak))"
   sDatumTag(181) = "BR"
   sDatumTxt(181) = "Tokyo  (Japan)"
   sDatumTag(182) = "BR"
   sDatumTxt(182) = "Tokyo  (Korea)"
   sDatumTag(183) = "BR"
   sDatumTxt(183) = "Tokyo  (Okinawa)"
   sDatumTag(184) = "BR"
   sDatumTxt(184) = "Tokyo  (MEAN FOR Japan, Korea, Okinawa)"
   sDatumTag(185) = "IN"
   sDatumTxt(185) = "Astro Tern Island (FRIG) 1961  (Tern Island)"
   sDatumTag(186) = "WD"
   sDatumTxt(186) = "WGS 1972  (Global Definition)"
   sDatumTag(187) = "WE"
   sDatumTxt(187) = "WGS 1984  (Global Definition)"
   sDatumTag(188) = "IN"
   sDatumTxt(188) = "Wake Island Astro 1952  (Wake Atoll)"
   sDatumTag(189) = "IN"
   sDatumTxt(189) = "Yacare  (Uruguay)"
   sDatumTag(190) = "IN"
   sDatumTxt(190) = "Zanderij  (Suriname)"
   For iLoop = 0 To 21
      frmEllipsoidData.cboEllipsoid.AddItem sEllipsoidTxt(iLoop)
   Next iLoop
   frmEllipsoidData.cboEllipsoid.ListIndex = 20
   For iLoop = 0 To 190
      frmEllipsoidData.cboDatum.AddItem sDatumTxt(iLoop)
   Next iLoop
   frmEllipsoidData.cboDatum.ListIndex = 187
End Sub
